==> axiom-1.3.0-src.zip: axiom-1.3.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/serializer/writer/Latin1XmlWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream.serializer.writer;

import java.io.IOException;
import java.io.OutputStream;

final class Latin1XmlWriter extends ASCIICompatibleXmlWriter {
    private final int maxChar;
    private UnmappableCharacterHandler unmappableCharacterHandler = UnmappableCharacterHandler.THROW_EXCEPTION;

    Latin1XmlWriter(OutputStream out, int maxChar) {
        super(out);
        this.maxChar = maxChar;
    }

    @Override
    public void setUnmappableCharacterHandler(UnmappableCharacterHandler unmappableCharacterHandler) throws IOException {
        this.unmappableCharacterHandler = unmappableCharacterHandler;
    }

    @Override
    protected void writeNonASCIICharacter(int codePoint) throws IOException {
        if (codePoint > maxChar) {
            unmappableCharacterHandler.processUnmappableCharacter(codePoint, this);
        } else {
            writeByte((byte)codePoint);
        }
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/serializer/writer/Latin1XmlWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream.serializer.writer;

import java.io.IOException;
import java.io.OutputStream;

final class Latin1XmlWriter extends ASCIICompatibleXmlWriter {
    private final int maxChar;
    private UnmappableCharacterHandler unmappableCharacterHandler =
            UnmappableCharacterHandler.THROW_EXCEPTION;

    Latin1XmlWriter(OutputStream out, int maxChar) {
        super(out);
        this.maxChar = maxChar;
    }

    @Override
    public void setUnmappableCharacterHandler(UnmappableCharacterHandler unmappableCharacterHandler)
            throws IOException {
        this.unmappableCharacterHandler = unmappableCharacterHandler;
    }

    @Override
    protected void writeNonASCIICharacter(int codePoint) throws IOException {
        if (codePoint > maxChar) {
            unmappableCharacterHandler.processUnmappableCharacter(codePoint, this);
        } else {
            writeByte((byte) codePoint);
        }
    }
}
